#!/usr/bin/env bash

bold=$(tput bold)      # ${bold}
normal=$(tput sgr0)    # ${normal}
yellow=$(tput setaf 3) # ${yellow}

# Zenity ablak megjelenítése
user_choice=$(zenity --list --radiolist --width='650' --height='370' \
  --title="Válaszd ki a nyelvet és a GPU-t!" \
  --text="Válassz az alábbi opciók közül:" \
  --column="Válassz" --column="GPU - Rendszer nyelv" \
   FALSE "AMD GPU - Angol Nyelv"  \
   FALSE "AMD GPU - Magyar Nyelv"  \
   FALSE "Nvidia GPU - Angol Nyelv"  \
   FALSE "Nvidia GPU - Magyar Nyelv")
if [[ $? -eq 1 ]]; then
   echo ${bold}${yellow}A script futása leállítva. Kilépés!${normal}
   exit 1
fi

# Nala telepítés
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Nala and changing DE - DEB Pkg${normal}
  echo
    sudo apt purge lightdm -y
    sudo apt install nala -y
    sudo apt install gdm3 -y
    sudo apt purge ubuntu-advantage-tools -y
    sudo apt install gnome-shell gnome-terminal eog gnome-system-monitor nautilus gnome-software-plugin-flatpak nautilus-extension-gnome-terminal gnome-software gedit -y
    flatpak remote-add --if-not-exists --user flathub https://flathub.org/repo/flathub.flatpakrepo
    sudo rm -rf /usr/lib/lightdm
    sudo rm -rf /var/lib/lightdm-data
    sudo rm -rf /usr/lib/python3/dist-packages/cinnamon
    sudo apt install ubuntu-advantage-tools -y
  echo
  echo ${bold}${yellow}Nala and changing DE - DEB Pkg ${normal}installed.
  echo ---------------------------------------------

# Creating autostart folder
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Creating autostart folder${normal}
  echo
    mkdir -p /home/$USER/.config/autostart
    sudo chown -R $USER:$GROUP /home/$USER/.config/autostart
  echo
  echo ${bold}${yellow}Autostart folder ${normal}created.
  echo ---------------------------------------------
  
# Autostarting ProgramScript after restart
echo ---------------------------------------------
  echo Installing ${bold}${yellow}ProgramScript Autostart${normal}
  echo
    sudo cp -a 3progs.sh.desktop /home/$USER/.config/autostart
    echo Exec=/home/$USER/.progs/3progs.sh >> /home/$USER/.config/autostart/3progs.sh.desktop
    sudo mkdir -p /home/$USER/.progs
    sudo chown -R $USER:$GROUP /home/$USER/.progs
    sudo cp -a 3progs.sh /home/$USER/.progs
    sudo chmod +x /home/$USER/.progs/3progs.sh
    sudo cp -a content-eng/. /home/$USER/.progs
  echo
  echo ${bold}${yellow}ProgramScript Autostart ${normal}installed.
  echo ---------------------------------------------

# Adding Custom rave command
echo ---------------------------------------------
  echo Installing ${bold}${yellow}rave command.${normal}
  echo
    sudo cp -a rave /usr/local/bin/
    sudo chmod +x /usr/local/bin/rave
    sudo cp -a rave-comp.sh /etc/bash_completion.d/
    sudo chmod +x /etc/bash_completion.d/rave-comp.sh
  echo
  echo ${bold}${yellow}Rave command with bash completion ${normal}installed.
  echo ---------------------------------------------

# Yaru Theme
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Yaru theme - DEB Pkg${normal}
  echo
    sudo apt install yaru-theme-gnome-shell yaru-theme-icon yaru-theme-gtk yaru-theme-sound -y
  echo
  echo ${bold}${yellow}Yaru theme ${normal}installed.
  echo ---------------------------------------------

# RP Cosmetics
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Setting correct Rave Theme${normal}
  echo
    sudo cp -a rave-pp /usr/share/pixmaps/faces/
    sudo sed -i '7d' /var/lib/AccountsService/users/$USER
    sudo sed -i '7 i Icon=/usr/share/pixmaps/faces/rave-pp' /var/lib/AccountsService/users/$USER
    sudo cp -a .themes /home/$USER/
    sudo cp -a .icons /home/$USER/
    sudo cp -a .mozilla /home/$USER/
    gsettings set org.gnome.desktop.interface gtk-theme 'Yaru-purple-dark'
    gsettings set org.gnome.desktop.interface cursor-theme 'Yaru'
    gsettings set org.gnome.desktop.interface icon-theme 'Yaru-purple-dark'
    gsettings set org.gnome.desktop.sound theme-name 'Yaru'
    gsettings set org.x.apps.portal color-scheme prefer-dark
    gsettings set org.gnome.desktop.screensaver lock-enabled false
    gsettings set org.gnome.desktop.session idle-delay 0
    gsettings set org.gnome.desktop.wm.preferences button-layout ":minimize,maximize,close"
    gsettings set org.gnome.mutter center-new-windows true
    sudo cp -a raveos-bg.png /usr/share/backgrounds/linuxmint-wilma/
    sudo cp -a linuxmint-wilma.xml /usr/share/gnome-background-properties/
    sudo cp -a gnome-shell /home/$USER/.local/share/
    sudo cp -a burn-my-windows /home/$USER/.config/
    sudo apt install git -y
    git clone --depth=1 https://github.com/realmazharhussain/gdm-tools.git
    sudo cp -a install.sh gdm-tools/
    cd gdm-tools
    ./install.sh
    cd -
    set-gdm-theme set Yaru-purple-dark /usr/share/backgrounds/linuxmint-wilma/raveos-bg.png
    dconf load / < raveui-*
    sudo rm -rf gdm-tools  
  echo
  echo ${bold}${yellow}Correct Rave Theme ${normal}set.
  echo ---------------------------------------------

# Disabling Geoclue
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Geoclue service disabling / masking${normal}
  echo
    sudo systemctl disable geoclue.service
    sudo systemctl mask geoclue.service
  echo
  echo ${bold}${yellow}Geoclue service disabling / masking ${normal}finished.
  echo ---------------------------------------------

# Enable x86
  echo ---------------------------------------------
  echo Enabling ${bold}${yellow}x86 architecture${normal}
  echo
     sudo dpkg --add-architecture i386
  echo
  echo ${bold}${yellow}x86 architecture ${normal}enabled.
  echo ---------------------------------------------

# Dependencies
  #echo ---------------------------------------------
  #echo Installing ${bold}${yellow}Dependencies${normal}
  #echo
    # egyelore uresen hagyjuk
  #echo
  #echo ${bold}${yellow}Dependencies ${normal}installed.
  #echo ---------------------------------------------

  echo Installing ${bold}${yellow}Liquorix - Gaming Kernel - DEB Pkg${normal}

    curl -s 'https://liquorix.net/install-liquorix.sh' | sudo bash

  echo ${bold}${yellow}Liquorix - Gaming Kernel ${normal}installed.
  echo ---------------------------------------------
  echo

# Flatseal - Flatpak app jogosultság beállító
echo
  echo ---------------------------------------------
  echo Installing ${bold}${yellow}Flatseal - flatpak${normal}

  flatpak install flathub com.github.tchx84.Flatseal --user -y
  sudo cp -a overrides /home/$USER/.local/share/flatpak

  echo ${bold}${yellow}Flatseal ${normal}installed.
  echo ---------------------------------------------
  echo

# Upgrading the System
  echo ---------------------------------------------
  echo ${bold}${yellow}Upgrading the System${normal}
  echo
    sudo apt update
    sudo apt upgrade -y
  echo
  echo ${bold}${yellow}System upgraded!${normal}
  echo ---------------------------------------------
  
fwupdmgr update

# Removing bloat
  echo ---------------------------------------------
  echo ${bold}${yellow}Removing bloat${normal}
  echo
  sudo cp -a default.plymouth /usr/share/plymouth/themes
  sudo chown -R $USER:$GROUP /home/$USER
  sudo apt purge xfce* libxfce* mugshot catfish compiz* gnome-logs synaptic menulibre libreoffice-draw libreoffice-impress libreoffice-math seahorse xed hypnotix mintstick celluloid xviewer xreader hexchat thingy mintbackup drawing transmission* timeshift redshift pix mintreport thunderbird onboard webapp-manager warpinator gnome-online-accounts rhythmbox mintinstall -y
  sudo rm -rf /usr/share/xfce4/applications
  echo
  echo ${bold}${yellow}Bloat removed!${normal}
  echo ---------------------------------------------


if [[ $user_choice = *"AMD GPU - Angol Nyelv"* ]]; then

# Wayland Auto-Enable
  echo
  echo ---------------------------------------------
  echo Enabling ${bold}${yellow}Wayland Window Manager${normal}
  echo
    
  echo
  echo ${bold}${yellow}Wayland Window Manager ${normal}enabled.
  echo ---------------------------------------------
  echo

fi

if [[ $user_choice = *"AMD GPU - Magyar Nyelv"* ]]; then
# Wayland Auto-Enable
  echo
  echo ---------------------------------------------
  echo Downloading ${bold}${yellow}Hungarian LangPack${normal}
  echo
    sudo apt install language-pack-gnome-hu language-pack-gnome-hu-base language-pack-hu language-pack-hu-base -y
  echo
  echo ${bold}${yellow}Hungarian LangPack ${normal}downloaded.
  echo ---------------------------------------------

fi

if [[ $user_choice = *"Nvidia GPU - Angol Nyelv"* ]]; then
  # stays in to prevent confusion
  echo
  echo 
  echo ---------------------------------------------
  
fi

if [[ $user_choice = *"Nvidia GPU - Magyar Nyelv"* ]]; then
  echo
  echo ---------------------------------------------
  echo Downloading ${bold}${yellow}Hungarian LangPack${normal}
  echo
    sudo apt install language-pack-gnome-hu language-pack-gnome-hu-base language-pack-hu language-pack-hu-base -y
  echo
  echo ${bold}${yellow}Hungarian LangPack ${normal}downloaded.
  echo ---------------------------------------------
  echo
fi

# Script end

echo ${bold}${yellow}The system will restart in 3 seconds...${normal}
echo ${bold}${yellow}3...${normal}
sleep 1
echo ${bold}${yellow}2...${normal}
sleep 1
echo ${bold}${yellow}1...${normal}
sleep 1

reboot
